@@ -5,7 +5,7 @@ import requests
 from .auth import CosS3Auth
 
 
-class Client(object):
+class Client:
     def __init__(self, secret_id, secret_key, region, bucket, scheme="https"):
         assert scheme in ["http", "https"]
 
@@ -16,16 +16,14 @@ class Client(object):
         self.bucket = bucket
         self.scheme = scheme
 
-        self.session = requests.Session()
-
-    def get_url(self, key):
+    def get_object_url(self, key):
         return urljoin(
             f"{self.scheme}://{self.bucket}.cos.{self.region}.myqcloud.com", key
         )
 
     def request(self, method, key, **kwargs):
-        url = self.get_url(key)
-        return self.session.request(
+        url = self.get_object_url(key)
+        return requests.request(
             method, url, auth=CosS3Auth(self.secret_id, self.secret_key, key), **kwargs,
         )
 
@@ -41,3 +39,10 @@ class Client(object):
     def put_local(self, key, local_path, **kwargs):
         with open(local_path, "rb") as f:
             return self.request("PUT", key, data=f, **kwargs)
+
+    def get_object_or_none(self, key):
+        """如果status_code是404，返回None"""
+        r = self.get_object(key)
+        if r.status_code == 404:
+            return
+        return r
